#include <algorithm>
#include <array>
#include <cassert>
#include <cstdint>
#include <iostream>
#include <numeric>
#include <ranges>
#include <vector>

template <typename T>
struct RMQ {
    const std::vector<T>& data_;
    std::vector<std::vector<uint32_t>> jmp_;

    RMQ(const std::vector<T>& data) : data_(data) {
        jmp_.emplace_back(data.size());
        std::iota(jmp_[0].begin(), jmp_[0].end(), 0);
        for (size_t pw = 1, k = 1; pw * 2 <= data_.size(); pw *= 2, ++k) {
            jmp_.emplace_back(data_.size() - pw * 2 + 1);
            for (size_t j = 0; j < jmp_[k].size(); ++j) {
                jmp_[k][j] = f(jmp_[k - 1][j], jmp_[k - 1][j + pw]);
            }
        }
    }

    // find the index m of the maximum in [l, r)
    uint32_t query(uint32_t l, uint32_t r) const {
        assert(l < r);
        uint32_t depth = 32 - std::countl_zero(r - l) - 1;
        return f(jmp_[depth][l], jmp_[depth][r - (1 << depth)]);
    }

    uint32_t f(uint32_t l, uint32_t r) const {
        return data_[l] >= data_[r] ? l : r;
    }
};

// 0 indexed template
struct BIT {
    int32_t n;
    std::vector<int32_t> f_tree;
    BIT(int32_t n): n(n) {
        f_tree.assign(n + 1, 0);
    }

    void update(int32_t x, int32_t v) {
        for (++x; x <= n; x += (x & -x)) {
            f_tree[x] += v;
        }
    }

    // f applied to range [0..x)
    int32_t query(int32_t x) const {
        int32_t res = 0;
        for (; x > 0; x -= (x & -x)) {
            res += f_tree[x];
        }

        return res;
    }

    int32_t query(int32_t l, int32_t r) const {
        return query(r) - query(l);
    }
};

int main() {
    int32_t n, k;
    std::cin >> n >> k;

    std::vector<int64_t> human(n), ai(n);
    for (auto& x : human) {
        std::cin >> x;
    }
    for (auto& x : ai) {
        std::cin >> x;
    }

    std::vector<int64_t> h(n + 1, 0), a(n + 1, 0);
    for (int32_t i = 0; i < n; ++i) {
        if (human[i] >= ai[i]) {
            h[i + 1] = human[i] - ai[i];
        } else {
            a[i + 1] = ai[i] - human[i];
        }
    }
    std::vector<int64_t> b = h;
    b.erase(b.begin());
    for (int32_t i = 0; i < n; ++i) {
        h[i + 1] += h[i];
    }
    for (int32_t i = 0; i < n; ++i) {
        a[i + 1] += a[i];
    }

    std::vector<int64_t> c(n + 1, 0);
    for (int32_t i = 0; i <= n; ++i) {
        c[i] = h[i] - k * a[i];
    }

    // c[r] - c[l] >= diff
    // val, op, l, r
    // op = add, leq, gt
    using Query = std::array<int64_t, 4>;
    std::vector<Query> queries;

    // l <= i <= m < j <= r
    RMQ rmq(b);
    std::vector<std::array<int32_t, 2>> stk;
    stk.push_back({0, n});
    while (!stk.empty()) {
        auto [l, r] = stk.back();
        stk.pop_back();
        int32_t m = rmq.query(l, r);
        int64_t diff = b[m] * (k + 1);
        if (m - l < r - m) {
            for (int32_t j = l; j <= m; ++j) {
                // C[x] - C[j] >= diff
                queries.push_back({c[j] + diff - 1, 2, m + 1, r + 1});
            }
        } else {
            for (int32_t j = m + 1; j <= r; ++j) {
                // C[j] - C[x] >= diff
                queries.push_back({c[j] - diff, 1, l, m + 1});
            }
        }

        if (l < m) {
            stk.push_back({l, m});
        }
        if (m + 1 < r) {
            stk.push_back({m + 1, r});
        }
    }

    for (uint32_t i = 0; i <= n; ++i) {
        queries.push_back({c[i], 0, i, i});
    }
    std::ranges::sort(queries);

    int64_t ans = 0;
    BIT bit(n + 1);
    for (const auto& [v, op, l, r] : queries) {
        if (op == 0) {
            assert(l == r);
            bit.update(l, 1);
        } else {
            int32_t cur = bit.query(l, r);
            if (op == 2) {
                ans += (r - l) - cur;
            } else {
                ans += cur;
            }
        }
    }

    std::cout << ans << '\n';

    return 0;
}
